@@ -1,15 +1,14 @@
-# -*- coding: utf-8 -*-
 """
 module containing a parametrized tests testing cross-python
 serialization via the pickle module.
 """
-import distutils.spawn
+import shutil
 import subprocess
 import textwrap
 
 import pytest
 
-pythonlist = ["python2.7", "python3.4", "python3.5"]
+pythonlist = ["python3.5", "python3.6", "python3.7"]
 
 
 @pytest.fixture(params=pythonlist)
@@ -23,9 +22,9 @@ def python2(request, python1):
     return Python(request.param, python1.picklefile)
 
 
-class Python(object):
+class Python:
     def __init__(self, version, picklefile):
-        self.pythonpath = distutils.spawn.find_executable(version)
+        self.pythonpath = shutil.which(version)
         if not self.pythonpath:
             pytest.skip("{!r} not found".format(version))
         self.picklefile = picklefile
