@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
 # content of conftest.py
 import pytest
 
 
 def pytest_collect_file(parent, path):
-    if path.ext == ".yml" and path.basename.startswith("test"):
+    if path.ext == ".yaml" and path.basename.startswith("test"):
         return YamlFile(path, parent)
 
 
@@ -19,7 +18,7 @@ class YamlFile(pytest.File):
 
 class YamlItem(pytest.Item):
     def __init__(self, name, parent, spec):
-        super(YamlItem, self).__init__(name, parent)
+        super().__init__(name, parent)
         self.spec = spec
 
     def runtest(self):
