@@ -1,15 +1,14 @@
-# -*- coding: utf-8 -*-
 import os
 import sys
 import textwrap
 
 import _pytest._code
 import pytest
-from _pytest.main import EXIT_NOTESTSCOLLECTED
+from _pytest.main import ExitCode
 from _pytest.nodes import Collector
 
 
-class TestModule(object):
+class TestModule:
     def test_failing_import(self, testdir):
         modcol = testdir.getmodulecol("import alksdjalskdjalkjals")
         pytest.raises(Collector.CollectError, modcol.collect)
@@ -117,12 +116,7 @@ class TestModule(object):
         """Check test modules collected which raise ImportError with unicode messages
         are handled properly (#2336).
         """
-        testdir.makepyfile(
-            u"""
-            # -*- coding: utf-8 -*-
-            raise ImportError(u'Something bad happened ☺')
-        """
-        )
+        testdir.makepyfile("raise ImportError('Something bad happened ☺')")
         result = testdir.runpytest()
         result.stdout.fnmatch_lines(
             [
@@ -134,7 +128,7 @@ class TestModule(object):
         assert result.ret == 2
 
 
-class TestClass(object):
+class TestClass:
     def test_class_with_init_warning(self, testdir):
         testdir.makepyfile(
             """
@@ -252,10 +246,10 @@ class TestClass(object):
         """
         )
         result = testdir.runpytest()
-        assert result.ret == EXIT_NOTESTSCOLLECTED
+        assert result.ret == ExitCode.NO_TESTS_COLLECTED
 
 
-class TestFunction(object):
+class TestFunction:
     def test_getmodulecollector(self, testdir):
         item = testdir.getitem("def test_func(): pass")
         modcol = item.getparent(pytest.Module)
@@ -514,11 +508,11 @@ class TestFunction(object):
         item = testdir.getitem("def test_func(): raise ValueError")
         config = item.config
 
-        class MyPlugin1(object):
+        class MyPlugin1:
             def pytest_pyfunc_call(self, pyfuncitem):
                 raise ValueError
 
-        class MyPlugin2(object):
+        class MyPlugin2:
             def pytest_pyfunc_call(self, pyfuncitem):
                 return True
 
@@ -664,7 +658,7 @@ class TestFunction(object):
         assert [x.originalname for x in items] == ["test_func", "test_func"]
 
 
-class TestSorting(object):
+class TestSorting:
     def test_check_equality(self, testdir):
         modcol = testdir.getmodulecol(
             """
@@ -679,8 +673,6 @@ class TestSorting(object):
 
         assert fn1 == fn2
         assert fn1 != modcol
-        if sys.version_info < (3, 0):
-            assert cmp(fn1, fn2) == 0  # NOQA
         assert hash(fn1) == hash(fn2)
 
         fn3 = testdir.collect_by_name(modcol, "test_fail")
@@ -718,7 +710,7 @@ class TestSorting(object):
         assert [item.name for item in colitems] == ["test_b", "test_a"]
 
 
-class TestConftestCustomization(object):
+class TestConftestCustomization:
     def test_pytest_pycollect_module(self, testdir):
         testdir.makeconftest(
             """
@@ -893,7 +885,7 @@ def test_modulecol_roundtrip(testdir):
     assert modcol.name == newcol.name
 
 
-class TestTracebackCutting(object):
+class TestTracebackCutting:
     def test_skip_simple(self):
         with pytest.raises(pytest.skip.Exception) as excinfo:
             pytest.skip("xxx")
@@ -1022,7 +1014,7 @@ class TestTracebackCutting(object):
         assert filter_traceback(tb[-1])
 
 
-class TestReportInfo(object):
+class TestReportInfo:
     def test_itemreport_reportinfo(self, testdir, linecomp):
         testdir.makeconftest(
             """
@@ -1148,7 +1140,7 @@ def test_unorderable_types(testdir):
     )
     result = testdir.runpytest()
     assert "TypeError" not in result.stdout.str()
-    assert result.ret == EXIT_NOTESTSCOLLECTED
+    assert result.ret == ExitCode.NO_TESTS_COLLECTED
 
 
 def test_collect_functools_partial(testdir):
@@ -1259,13 +1251,7 @@ def test_class_injection_does_not_break_collection(testdir):
 def test_syntax_error_with_non_ascii_chars(testdir):
     """Fix decoding issue while formatting SyntaxErrors during collection (#578)
     """
-    testdir.makepyfile(
-        u"""
-    # -*- coding: utf-8 -*-
-
-    ☃
-    """
-    )
+    testdir.makepyfile("☃")
     result = testdir.runpytest()
     result.stdout.fnmatch_lines(["*ERROR collecting*", "*SyntaxError*", "*1 error in*"])
 
