@@ -1,8 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import pprint
 import sys
@@ -12,12 +7,11 @@ import py
 
 import pytest
 from _pytest.main import _in_venv
-from _pytest.main import EXIT_INTERRUPTED
-from _pytest.main import EXIT_NOTESTSCOLLECTED
+from _pytest.main import ExitCode
 from _pytest.main import Session
 
 
-class TestCollector(object):
+class TestCollector:
     def test_collect_versus_item(self):
         from pytest import Collector, Item
 
@@ -38,8 +32,6 @@ class TestCollector(object):
 
         assert fn1 == fn2
         assert fn1 != modcol
-        if sys.version_info < (3, 0):
-            assert cmp(fn1, fn2) == 0  # NOQA
         assert hash(fn1) == hash(fn2)
 
         fn3 = testdir.collect_by_name(modcol, "test_fail")
@@ -109,7 +101,7 @@ class TestCollector(object):
         result.stdout.fnmatch_lines(["collected 0 items", "*no tests ran in*"])
 
 
-class TestCollectFS(object):
+class TestCollectFS:
     def test_ignored_certain_directories(self, testdir):
         tmpdir = testdir.tmpdir
         tmpdir.ensure("build", "test_notfound.py")
@@ -246,11 +238,11 @@ class TestCollectFS(object):
             assert [x.name for x in items] == ["test_%s" % dirname]
 
 
-class TestCollectPluginHookRelay(object):
+class TestCollectPluginHookRelay:
     def test_pytest_collect_file(self, testdir):
         wascalled = []
 
-        class Plugin(object):
+        class Plugin:
             def pytest_collect_file(self, path, parent):
                 if not path.basename.startswith("."):
                     # Ignore hidden files, e.g. .testmondata.
@@ -264,7 +256,7 @@ class TestCollectPluginHookRelay(object):
     def test_pytest_collect_directory(self, testdir):
         wascalled = []
 
-        class Plugin(object):
+        class Plugin:
             def pytest_collect_directory(self, path, parent):
                 wascalled.append(path.basename)
 
@@ -275,7 +267,7 @@ class TestCollectPluginHookRelay(object):
         assert "world" in wascalled
 
 
-class TestPrunetraceback(object):
+class TestPrunetraceback:
     def test_custom_repr_failure(self, testdir):
         p = testdir.makepyfile(
             """
@@ -324,7 +316,7 @@ class TestPrunetraceback(object):
         result.stdout.fnmatch_lines(["*ERROR collecting*", "*header1*"])
 
 
-class TestCustomConftests(object):
+class TestCustomConftests:
     def test_ignore_collect_path(self, testdir):
         testdir.makeconftest(
             """
@@ -354,7 +346,7 @@ class TestCustomConftests(object):
         assert result.ret == 0
         result.stdout.fnmatch_lines(["*1 passed*"])
         result = testdir.runpytest()
-        assert result.ret == EXIT_NOTESTSCOLLECTED
+        assert result.ret == ExitCode.NO_TESTS_COLLECTED
         result.stdout.fnmatch_lines(["*collected 0 items*"])
 
     def test_collectignore_exclude_on_option(self, testdir):
@@ -371,7 +363,7 @@ class TestCustomConftests(object):
         testdir.mkdir("hello")
         testdir.makepyfile(test_world="def test_hello(): pass")
         result = testdir.runpytest()
-        assert result.ret == EXIT_NOTESTSCOLLECTED
+        assert result.ret == ExitCode.NO_TESTS_COLLECTED
         assert "passed" not in result.stdout.str()
         result = testdir.runpytest("--XX")
         assert result.ret == 0
@@ -391,7 +383,7 @@ class TestCustomConftests(object):
         testdir.makepyfile(test_world="def test_hello(): pass")
         testdir.makepyfile(test_welt="def test_hallo(): pass")
         result = testdir.runpytest()
-        assert result.ret == EXIT_NOTESTSCOLLECTED
+        assert result.ret == ExitCode.NO_TESTS_COLLECTED
         result.stdout.fnmatch_lines(["*collected 0 items*"])
         result = testdir.runpytest("--XX")
         assert result.ret == 0
@@ -445,7 +437,7 @@ class TestCustomConftests(object):
         result.stdout.fnmatch_lines(["*MyModule1*", "*MyModule2*", "*test_x*"])
 
 
-class TestSession(object):
+class TestSession:
     def test_parsearg(self, testdir):
         p = testdir.makepyfile("def test_func(): pass")
         subdir = testdir.mkdir("sub")
@@ -494,7 +486,7 @@ class TestSession(object):
         p = testdir.makepyfile("def test_func(): pass")
         id = "::".join([p.basename, "test_func"])
         items, hookrec = testdir.inline_genitems(id)
-        (item,) = items
+        item, = items
         assert item.name == "test_func"
         newid = item.nodeid
         assert newid == id
@@ -613,9 +605,9 @@ class TestSession(object):
         testdir.makepyfile("def test_func(): pass")
         items, hookrec = testdir.inline_genitems()
         assert len(items) == 1
-        (item,) = items
+        item, = items
         items2, hookrec = testdir.inline_genitems(item.nodeid)
-        (item2,) = items2
+        item2, = items2
         assert item2.name == item.name
         assert item2.fspath == item.fspath
 
@@ -630,13 +622,13 @@ class TestSession(object):
         arg = p.basename + "::TestClass::test_method"
         items, hookrec = testdir.inline_genitems(arg)
         assert len(items) == 1
-        (item,) = items
+        item, = items
         assert item.nodeid.endswith("TestClass::test_method")
         # ensure we are reporting the collection of the single test item (#2464)
         assert [x.name for x in self.get_reported_items(hookrec)] == ["test_method"]
 
 
-class Test_getinitialnodes(object):
+class Test_getinitialnodes:
     def test_global_file(self, testdir, tmpdir):
         x = tmpdir.ensure("x.py")
         with tmpdir.as_cwd():
@@ -670,7 +662,7 @@ class Test_getinitialnodes(object):
             assert col.config is config
 
 
-class Test_genitems(object):
+class Test_genitems:
     def test_check_collect_hashes(self, testdir):
         p = testdir.makepyfile(
             """
@@ -783,7 +775,7 @@ def test_matchnodes_two_collections_same_file(testdir):
     res.stdout.fnmatch_lines(["*1 passed*"])
 
 
-class TestNodekeywords(object):
+class TestNodekeywords:
     def test_no_under(self, testdir):
         modcol = testdir.getmodulecol(
             """
@@ -1179,7 +1171,7 @@ def test_collectignore_via_conftest(testdir, monkeypatch):
     ignore_me.ensure("conftest.py").write("assert 0, 'should_not_be_called'")
 
     result = testdir.runpytest()
-    assert result.ret == EXIT_NOTESTSCOLLECTED
+    assert result.ret == ExitCode.NO_TESTS_COLLECTED
 
 
 def test_collect_pkg_init_and_file_in_args(testdir):
@@ -1211,18 +1203,6 @@ def test_collect_pkg_init_and_file_in_args(testdir):
     )
 
 
-def test_collect_pkg_init_only(testdir):
-    subdir = testdir.mkdir("sub")
-    init = subdir.ensure("__init__.py")
-    init.write("def test_init(): pass")
-
-    result = testdir.runpytest(str(init))
-    result.stdout.fnmatch_lines(["*no tests ran in*"])
-
-    result = testdir.runpytest("-v", "-o", "python_files=*.py", str(init))
-    result.stdout.fnmatch_lines(["sub/__init__.py::test_init PASSED*", "*1 passed in*"])
-
-
 @pytest.mark.skipif(
     not hasattr(py.path.local, "mksymlinkto"),
     reason="symlink not available on this platform",
@@ -1253,7 +1233,7 @@ def test_collect_sub_with_symlinks(use_pkg, testdir):
 def test_collector_respects_tbstyle(testdir):
     p1 = testdir.makepyfile("assert 0")
     result = testdir.runpytest(p1, "--tb=native")
-    assert result.ret == EXIT_INTERRUPTED
+    assert result.ret == ExitCode.INTERRUPTED
     result.stdout.fnmatch_lines(
         [
             "*_ ERROR collecting test_collector_respects_tbstyle.py _*",
