@@ -1,27 +1,19 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import sys
 import textwrap
 
+import importlib_metadata
+
 import _pytest._code
 import pytest
-from _pytest.compat import importlib_metadata
 from _pytest.config import _iter_rewritable_modules
 from _pytest.config.exceptions import UsageError
 from _pytest.config.findpaths import determine_setup
 from _pytest.config.findpaths import get_common_ancestor
 from _pytest.config.findpaths import getcfg
-from _pytest.main import EXIT_INTERRUPTED
-from _pytest.main import EXIT_NOTESTSCOLLECTED
-from _pytest.main import EXIT_OK
-from _pytest.main import EXIT_TESTSFAILED
-from _pytest.main import EXIT_USAGEERROR
+from _pytest.main import ExitCode
 
 
-class TestParseIni(object):
+class TestParseIni:
     @pytest.mark.parametrize(
         "section, filename", [("pytest", "pytest.ini"), ("tool:pytest", "setup.cfg")]
     )
@@ -130,12 +122,6 @@ class TestParseIni(object):
         config = testdir.parseconfigure(sub)
         assert config.getini("minversion") == "2.0"
 
-    def test_ini_parse_error(self, testdir):
-        testdir.tmpdir.join("pytest.ini").write("addopts = -x")
-        result = testdir.runpytest()
-        assert result.ret != 0
-        result.stderr.fnmatch_lines(["ERROR: *pytest.ini:1: no section header defined"])
-
     @pytest.mark.xfail(reason="probably not needed")
     def test_confcutdir(self, testdir):
         sub = testdir.mkdir("sub")
@@ -150,7 +136,7 @@ class TestParseIni(object):
         assert result.ret == 0
 
 
-class TestConfigCmdlineParsing(object):
+class TestConfigCmdlineParsing:
     def test_parsing_again_fails(self, testdir):
         config = testdir.parseconfig()
         pytest.raises(AssertionError, lambda: config.parse([]))
@@ -200,10 +186,10 @@ class TestConfigCmdlineParsing(object):
 
         temp_ini_file = normpath(str(temp_ini_file))
         ret = pytest.main(["-c", temp_ini_file])
-        assert ret == _pytest.main.EXIT_OK
+        assert ret == ExitCode.OK
 
 
-class TestConfigAPI(object):
+class TestConfigAPI:
     def test_config_trace(self, testdir):
         config = testdir.parseconfig()
         values = []
@@ -224,12 +210,9 @@ class TestConfigAPI(object):
             assert config.getoption(x) == "this"
         pytest.raises(ValueError, config.getoption, "qweqwe")
 
-    @pytest.mark.skipif("sys.version_info[0] < 3")
     def test_config_getoption_unicode(self, testdir):
         testdir.makeconftest(
             """
-            from __future__ import unicode_literals
-
             def pytest_addoption(parser):
                 parser.addoption('--hello', type=str)
         """
@@ -431,24 +414,18 @@ class TestConfigAPI(object):
     @pytest.mark.parametrize(
         "names, expected",
         [
-            # dist-info based distributions root are files as will be put in PYTHONPATH
             (["bar.py"], ["bar"]),
-            (["foo/bar.py"], ["bar"]),
-            (["foo/bar.pyc"], []),
-            (["foo/__init__.py"], ["foo"]),
-            (["bar/__init__.py", "xz.py"], ["bar", "xz"]),
-            (["setup.py"], []),
-            # egg based distributions root contain the files from the dist root
-            (["src/bar/__init__.py"], ["bar"]),
-            (["src/bar/__init__.py", "setup.py"], ["bar"]),
-            (["source/python/bar/__init__.py", "setup.py"], ["bar"]),
+            (["foo", "bar.py"], []),
+            (["foo", "bar.pyc"], []),
+            (["foo", "__init__.py"], ["foo"]),
+            (["foo", "bar", "__init__.py"], []),
         ],
     )
     def test_iter_rewritable_modules(self, names, expected):
-        assert list(_iter_rewritable_modules(names)) == expected
+        assert list(_iter_rewritable_modules(["/".join(names)])) == expected
 
 
-class TestConfigFromdictargs(object):
+class TestConfigFromdictargs:
     def test_basic_behavior(self, _sys_snapshot):
         from _pytest.config import Config
 
@@ -546,17 +523,17 @@ def test_options_on_small_file_do_not_blow_up(testdir):
 def test_preparse_ordering_with_setuptools(testdir, monkeypatch):
     monkeypatch.delenv("PYTEST_DISABLE_PLUGIN_AUTOLOAD", raising=False)
 
-    class EntryPoint(object):
+    class EntryPoint:
         name = "mytestplugin"
         group = "pytest11"
 
         def load(self):
-            class PseudoPlugin(object):
+            class PseudoPlugin:
                 x = 42
 
             return PseudoPlugin()
 
-    class Dist(object):
+    class Dist:
         files = ()
         entry_points = (EntryPoint(),)
 
@@ -578,14 +555,14 @@ def test_preparse_ordering_with_setuptools(testdir, monkeypatch):
 def test_setuptools_importerror_issue1479(testdir, monkeypatch):
     monkeypatch.delenv("PYTEST_DISABLE_PLUGIN_AUTOLOAD", raising=False)
 
-    class DummyEntryPoint(object):
+    class DummyEntryPoint:
         name = "mytestplugin"
         group = "pytest11"
 
         def load(self):
             raise ImportError("Don't hide me!")
 
-    class Distribution(object):
+    class Distribution:
         version = "1.0"
         files = ("foo.txt",)
         entry_points = (DummyEntryPoint(),)
@@ -627,14 +604,14 @@ def test_plugin_preparse_prevents_setuptools_loading(testdir, monkeypatch, block
 
     plugin_module_placeholder = object()
 
-    class DummyEntryPoint(object):
+    class DummyEntryPoint:
         name = "mytestplugin"
         group = "pytest11"
 
         def load(self):
             return plugin_module_placeholder
 
-    class Distribution(object):
+    class Distribution:
         version = "1.0"
         files = ("foo.txt",)
         entry_points = (DummyEntryPoint(),)
@@ -659,7 +636,7 @@ def test_plugin_preparse_prevents_setuptools_loading(testdir, monkeypatch, block
     "parse_args,should_load", [(("-p", "mytestplugin"), True), ((), False)]
 )
 def test_disable_plugin_autoload(testdir, monkeypatch, parse_args, should_load):
-    class DummyEntryPoint(object):
+    class DummyEntryPoint:
         project_name = name = "mytestplugin"
         group = "pytest11"
         version = "1.0"
@@ -667,11 +644,11 @@ def test_disable_plugin_autoload(testdir, monkeypatch, parse_args, should_load):
         def load(self):
             return sys.modules[self.name]
 
-    class Distribution(object):
+    class Distribution:
         entry_points = (DummyEntryPoint(),)
         files = ()
 
-    class PseudoPlugin(object):
+    class PseudoPlugin:
         x = 42
 
     def distributions():
@@ -746,7 +723,7 @@ def test_consider_args_after_options_for_rootdir(testdir, args):
 @pytest.mark.skipif("sys.platform == 'win32'")
 def test_toolongargs_issue224(testdir):
     result = testdir.runpytest("-m", "hello" * 500)
-    assert result.ret == EXIT_NOTESTSCOLLECTED
+    assert result.ret == ExitCode.NO_TESTS_COLLECTED
 
 
 def test_config_in_subdirectory_colon_command_line_issue2148(testdir):
@@ -783,7 +760,7 @@ def test_notify_exception(testdir, capfd):
     out, err = capfd.readouterr()
     assert "ValueError" in err
 
-    class A(object):
+    class A:
         def pytest_internalerror(self, excrepr):
             return True
 
@@ -803,13 +780,13 @@ def test_notify_exception(testdir, capfd):
 def test_no_terminal_discovery_error(testdir):
     testdir.makepyfile("raise TypeError('oops!')")
     result = testdir.runpytest("-p", "no:terminal", "--collect-only")
-    assert result.ret == EXIT_INTERRUPTED
+    assert result.ret == ExitCode.INTERRUPTED
 
 
 def test_load_initial_conftest_last_ordering(testdir, _config_for_test):
     pm = _config_for_test.pluginmanager
 
-    class My(object):
+    class My:
         def pytest_load_initial_conftests(self):
             pass
 
@@ -847,15 +824,15 @@ def test_collect_pytest_prefix_bug_integration(testdir):
 def test_collect_pytest_prefix_bug(pytestconfig):
     """Ensure we collect only actual functions from conftest files (#3775)"""
 
-    class Dummy(object):
-        class pytest_something(object):
+    class Dummy:
+        class pytest_something:
             pass
 
     pm = pytestconfig.pluginmanager
     assert pm.parse_hookimpl_opts(Dummy(), "pytest_something") is None
 
 
-class TestRootdir(object):
+class TestRootdir:
     def test_simple_noini(self, tmpdir):
         assert get_common_ancestor([tmpdir]) == tmpdir
         a = tmpdir.mkdir("a")
@@ -913,7 +890,7 @@ class TestRootdir(object):
         assert rootdir == tmpdir
 
 
-class TestOverrideIniArgs(object):
+class TestOverrideIniArgs:
     @pytest.mark.parametrize("name", "setup.cfg tox.ini pytest.ini".split())
     def test_override_ini_names(self, testdir, name):
         section = "[pytest]" if name != "setup.cfg" else "[tool:pytest]"
@@ -1112,7 +1089,7 @@ class TestOverrideIniArgs(object):
                 % (testdir.request.config._parser.optparser.prog,)
             ]
         )
-        assert result.ret == _pytest.main.EXIT_USAGEERROR
+        assert result.ret == _pytest.main.ExitCode.USAGE_ERROR
 
     def test_override_ini_does_not_contain_paths(self, _config_for_test, _sys_snapshot):
         """Check that -o no longer swallows all options after it (#3103)"""
@@ -1201,13 +1178,13 @@ def test_help_and_version_after_argument_error(testdir):
     )
     # Does not display full/default help.
     assert "to see available markers type: pytest --markers" not in result.stdout.lines
-    assert result.ret == EXIT_USAGEERROR
+    assert result.ret == ExitCode.USAGE_ERROR
 
     result = testdir.runpytest("--version")
     result.stderr.fnmatch_lines(
         ["*pytest*{}*imported from*".format(pytest.__version__)]
     )
-    assert result.ret == EXIT_USAGEERROR
+    assert result.ret == ExitCode.USAGE_ERROR
 
 
 def test_config_does_not_load_blocked_plugin_from_args(testdir):
@@ -1215,11 +1192,11 @@ def test_config_does_not_load_blocked_plugin_from_args(testdir):
     p = testdir.makepyfile("def test(capfd): pass")
     result = testdir.runpytest(str(p), "-pno:capture")
     result.stdout.fnmatch_lines(["E       fixture 'capfd' not found"])
-    assert result.ret == EXIT_TESTSFAILED
+    assert result.ret == ExitCode.TESTS_FAILED
 
     result = testdir.runpytest(str(p), "-pno:capture", "-s")
     result.stderr.fnmatch_lines(["*: error: unrecognized arguments: -s"])
-    assert result.ret == EXIT_USAGEERROR
+    assert result.ret == ExitCode.USAGE_ERROR
 
 
 @pytest.mark.parametrize(
@@ -1245,7 +1222,7 @@ def test_config_blocked_default_plugins(testdir, plugin):
     result = testdir.runpytest(str(p), "-pno:%s" % plugin)
 
     if plugin == "python":
-        assert result.ret == EXIT_USAGEERROR
+        assert result.ret == ExitCode.USAGE_ERROR
         result.stderr.fnmatch_lines(
             [
                 "ERROR: not found: */test_config_blocked_default_plugins.py",
@@ -1254,13 +1231,13 @@ def test_config_blocked_default_plugins(testdir, plugin):
         )
         return
 
-    assert result.ret == EXIT_OK
+    assert result.ret == ExitCode.OK
     if plugin != "terminal":
         result.stdout.fnmatch_lines(["* 1 passed in *"])
 
     p = testdir.makepyfile("def test(): assert 0")
     result = testdir.runpytest(str(p), "-pno:%s" % plugin)
-    assert result.ret == EXIT_TESTSFAILED
+    assert result.ret == ExitCode.TESTS_FAILED
     if plugin != "terminal":
         result.stdout.fnmatch_lines(["* 1 failed in *"])
     else:
