@@ -1,12 +1,4 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
-import platform
-import sys
-from datetime import datetime
 from xml.dom import minidom
 
 import py
@@ -36,7 +28,7 @@ def assert_attr(node, **kwargs):
     assert on_node == expected
 
 
-class DomNode(object):
+class DomNode:
     def __init__(self, dom):
         self.__node = dom
 
@@ -49,16 +41,6 @@ class DomNode(object):
     def _by_tag(self, tag):
         return self.__node.getElementsByTagName(tag)
 
-    @property
-    def children(self):
-        return [type(self)(x) for x in self.__node.childNodes]
-
-    @property
-    def get_unique_child(self):
-        children = self.children
-        assert len(children) == 1
-        return children[0]
-
     def find_nth_by_tag(self, tag, n):
         items = self._by_tag(tag)
         try:
@@ -93,11 +75,11 @@ class DomNode(object):
         return self.__node.tagName
 
     @property
-    def next_sibling(self):
+    def next_siebling(self):
         return type(self)(self.__node.nextSibling)
 
 
-class TestPython(object):
+class TestPython:
     def test_summing_simple(self, testdir):
         testdir.makepyfile(
             """
@@ -147,30 +129,6 @@ class TestPython(object):
         node = dom.find_first_by_tag("testsuite")
         node.assert_attr(name="pytest", errors=1, failures=2, skipped=1, tests=5)
 
-    def test_hostname_in_xml(self, testdir):
-        testdir.makepyfile(
-            """
-            def test_pass():
-                pass
-        """
-        )
-        result, dom = runandparse(testdir)
-        node = dom.find_first_by_tag("testsuite")
-        node.assert_attr(hostname=platform.node())
-
-    def test_timestamp_in_xml(self, testdir):
-        testdir.makepyfile(
-            """
-            def test_pass():
-                pass
-        """
-        )
-        start_time = datetime.now()
-        result, dom = runandparse(testdir)
-        node = dom.find_first_by_tag("testsuite")
-        timestamp = datetime.strptime(node["timestamp"], "%Y-%m-%dT%H:%M:%S.%f")
-        assert start_time <= timestamp < datetime.now()
-
     def test_timing_function(self, testdir):
         testdir.makepyfile(
             """
@@ -426,11 +384,11 @@ class TestPython(object):
         fnode = tnode.find_first_by_tag("failure")
         fnode.assert_attr(message="ValueError: 42")
         assert "ValueError" in fnode.toxml()
-        systemout = fnode.next_sibling
+        systemout = fnode.next_siebling
         assert systemout.tag == "system-out"
         assert "hello-stdout" in systemout.toxml()
         assert "info msg" not in systemout.toxml()
-        systemerr = systemout.next_sibling
+        systemerr = systemout.next_siebling
         assert systemerr.tag == "system-err"
         assert "hello-stderr" in systemerr.toxml()
         assert "info msg" not in systemerr.toxml()
@@ -609,20 +567,19 @@ class TestPython(object):
     def test_unicode(self, testdir):
         value = "hx\xc4\x85\xc4\x87\n"
         testdir.makepyfile(
-            """
+            """\
             # coding: latin1
             def test_hello():
                 print(%r)
                 assert 0
-        """
+            """
             % value
         )
         result, dom = runandparse(testdir)
         assert result.ret == 1
         tnode = dom.find_first_by_tag("testcase")
         fnode = tnode.find_first_by_tag("failure")
-        if not sys.platform.startswith("java"):
-            assert "hx" in fnode.toxml()
+        assert "hx" in fnode.toxml()
 
     def test_assertion_binchars(self, testdir):
         """this test did fail when the escaping wasnt strict"""
@@ -739,7 +696,7 @@ def test_mangle_test_address():
 def test_dont_configure_on_slaves(tmpdir):
     gotten = []
 
-    class FakeConfig(object):
+    class FakeConfig:
         def __init__(self):
             self.pluginmanager = self
             self.option = self
@@ -762,7 +719,7 @@ def test_dont_configure_on_slaves(tmpdir):
     assert len(gotten) == 1
 
 
-class TestNonPython(object):
+class TestNonPython:
     def test_summing_simple(self, testdir):
         testdir.makeconftest(
             """
@@ -916,12 +873,12 @@ def test_logxml_check_isdir(testdir):
 
 def test_escaped_parametrized_names_xml(testdir):
     testdir.makepyfile(
-        """
+        """\
         import pytest
-        @pytest.mark.parametrize('char', [u"\\x00"])
+        @pytest.mark.parametrize('char', ["\\x00"])
         def test_func(char):
             assert char
-    """
+        """
     )
     result, dom = runandparse(testdir)
     assert result.ret == 0
@@ -965,7 +922,7 @@ def test_double_colon_split_method_issue469(testdir):
 def test_unicode_issue368(testdir):
     path = testdir.tmpdir.join("test.xml")
     log = LogXML(str(path), None)
-    ustr = u"ВНИ!"
+    ustr = "ВНИ!"
 
     class Report(BaseReport):
         longrepr = ustr
@@ -1137,20 +1094,6 @@ def test_random_report_log_xdist(testdir, monkeypatch):
     assert failed == ["test_x[22]"]
 
 
-def test_root_testsuites_tag(testdir):
-    testdir.makepyfile(
-        """
-        def test_x():
-            pass
-    """
-    )
-    _, dom = runandparse(testdir)
-    root = dom.get_unique_child
-    assert root.tag == "testsuites"
-    suite_node = root.get_unique_child
-    assert suite_node.tag == "testsuite"
-
-
 def test_runs_twice(testdir):
     f = testdir.makepyfile(
         """
@@ -1223,13 +1166,13 @@ def test_fancy_items_regression(testdir):
 
     pprint.pprint(items)
     assert items == [
-        u"conftest a",
-        u"conftest a",
-        u"conftest b",
-        u"test_fancy_items_regression a",
-        u"test_fancy_items_regression a",
-        u"test_fancy_items_regression b",
-        u"test_fancy_items_regression test_pass",
+        "conftest a",
+        "conftest a",
+        "conftest b",
+        "test_fancy_items_regression a",
+        "test_fancy_items_regression a",
+        "test_fancy_items_regression b",
+        "test_fancy_items_regression test_pass",
     ]
 
 
@@ -1409,39 +1352,3 @@ def test_logging_passing_tests_disabled_does_not_log_test_output(testdir):
     node = dom.find_first_by_tag("testcase")
     assert len(node.find_by_tag("system-err")) == 0
     assert len(node.find_by_tag("system-out")) == 0
-
-
-@pytest.mark.parametrize("junit_logging", ["no", "system-out", "system-err"])
-def test_logging_passing_tests_disabled_logs_output_for_failing_test_issue5430(
-    testdir, junit_logging
-):
-    testdir.makeini(
-        """
-        [pytest]
-        junit_log_passing_tests=False
-    """
-    )
-    testdir.makepyfile(
-        """
-        import pytest
-        import logging
-        import sys
-
-        def test_func():
-            logging.warning('hello')
-            assert 0
-    """
-    )
-    result, dom = runandparse(testdir, "-o", "junit_logging=%s" % junit_logging)
-    assert result.ret == 1
-    node = dom.find_first_by_tag("testcase")
-    if junit_logging == "system-out":
-        assert len(node.find_by_tag("system-err")) == 0
-        assert len(node.find_by_tag("system-out")) == 1
-    elif junit_logging == "system-err":
-        assert len(node.find_by_tag("system-err")) == 1
-        assert len(node.find_by_tag("system-out")) == 0
-    else:
-        assert junit_logging == "no"
-        assert len(node.find_by_tag("system-err")) == 0
-        assert len(node.find_by_tag("system-out")) == 0
