@@ -1,15 +1,9 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import sys
-
-import six
+from unittest import mock
 
 import pytest
-from _pytest.main import EXIT_INTERRUPTED
+from _pytest.main import ExitCode
 from _pytest.mark import EMPTY_PARAMETERSET_OPTION
 from _pytest.mark import MarkGenerator as Mark
 from _pytest.nodes import Collector
@@ -17,17 +11,12 @@ from _pytest.nodes import Node
 from _pytest.warning_types import PytestDeprecationWarning
 from _pytest.warnings import SHOW_PYTEST_WARNINGS_ARG
 
-try:
-    import mock
-except ImportError:
-    import unittest.mock as mock
-
 ignore_markinfo = pytest.mark.filterwarnings(
     "ignore:MarkInfo objects:pytest.RemovedInPytest4Warning"
 )
 
 
-class TestMark(object):
+class TestMark:
     @pytest.mark.parametrize("attr", ["mark", "param"])
     @pytest.mark.parametrize("modulename", ["py.test", "pytest"])
     def test_pytest_exists_in_namespace_all(self, attr, modulename):
@@ -42,7 +31,7 @@ class TestMark(object):
         def some_function(abc):
             pass
 
-        class SomeClass(object):
+        class SomeClass:
             pass
 
         assert pytest.mark.foo(some_function) is some_function
@@ -435,7 +424,7 @@ def test_parametrize_iterator(testdir):
     result.stdout.fnmatch_lines(["*3 passed*"])
 
 
-class TestFunctional(object):
+class TestFunctional:
     def test_merging_markers_deep(self, testdir):
         # issue 199 - propagate markers into nested classes
         p = testdir.makepyfile(
@@ -704,7 +693,7 @@ class TestFunctional(object):
         reprec.assertoutcome(skipped=1)
 
 
-class TestKeywordSelection(object):
+class TestKeywordSelection:
     def test_select_simple(self, testdir):
         file_test = testdir.makepyfile(
             """
@@ -835,7 +824,7 @@ class TestKeywordSelection(object):
         assert_test_is_not_selected("()")
 
 
-class TestMarkDecorator(object):
+class TestMarkDecorator:
     @pytest.mark.parametrize(
         "lhs, rhs, expected",
         [
@@ -914,7 +903,7 @@ def test_parameterset_for_fail_at_collect(testdir):
             "*= 1 error in *",
         ]
     )
-    assert result.ret == EXIT_INTERRUPTED
+    assert result.ret == ExitCode.INTERRUPTED
 
 
 def test_parameterset_for_parametrize_bad_markname(testdir):
@@ -971,7 +960,6 @@ def test_markers_from_parametrize(testdir):
     """#3605"""
     testdir.makepyfile(
         """
-        from __future__ import print_function
         import pytest
 
         first_custom_mark = pytest.mark.custom_marker
@@ -1008,11 +996,8 @@ def test_markers_from_parametrize(testdir):
 def test_pytest_param_id_requires_string():
     with pytest.raises(TypeError) as excinfo:
         pytest.param(id=True)
-    (msg,) = excinfo.value.args
-    if six.PY2:
-        assert msg == "Expected id to be a string, got <type 'bool'>: True"
-    else:
-        assert msg == "Expected id to be a string, got <class 'bool'>: True"
+    msg, = excinfo.value.args
+    assert msg == "Expected id to be a string, got <class 'bool'>: True"
 
 
 @pytest.mark.parametrize("s", (None, "hello world"))
@@ -1025,7 +1010,7 @@ def test_pytest_param_warning_on_unknown_kwargs():
         # typo, should be marks=
         pytest.param(1, 2, mark=pytest.mark.xfail())
     assert warninfo[0].filename == __file__
-    (msg,) = warninfo[0].message.args
+    msg, = warninfo[0].message.args
     assert msg == (
         "pytest.param() got unexpected keyword arguments: ['mark'].\n"
         "This will be an error in future versions."
