@@ -1,8 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import re
 import warnings
 
@@ -31,7 +26,7 @@ def test_recwarn_functional(testdir):
     reprec.assertoutcome(passed=1)
 
 
-class TestWarningsRecorderChecker(object):
+class TestWarningsRecorderChecker:
     def test_recording(self):
         rec = WarningsRecorder()
         with rec:
@@ -78,7 +73,7 @@ class TestWarningsRecorderChecker(object):
                         pass  # can't enter twice
 
 
-class TestDeprecatedCall(object):
+class TestDeprecatedCall:
     """test pytest.deprecated_call()"""
 
     def dep(self, i, j=None):
@@ -210,7 +205,7 @@ class TestDeprecatedCall(object):
                 warnings.warn("this is not here", DeprecationWarning)
 
 
-class TestWarns(object):
+class TestWarns:
     def test_strings(self):
         # different messages, b/c Python suppresses multiple identical warnings
         source1 = "warnings.warn('w1', RuntimeWarning)"
@@ -225,7 +220,7 @@ class TestWarns(object):
         assert len(warninfo) == 3
         for w in warninfo:
             assert w.filename == __file__
-            (msg,) = w.message.args
+            msg, = w.message.args
             assert msg.startswith("warns(..., 'code(as_a_string)') is deprecated")
 
     def test_function(self):
