@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-import sys
-
 import pytest
 
 
@@ -210,8 +207,7 @@ def test_xfail_handling(testdir):
 
     # because we are writing to the same file, mtime might not be affected enough to
     # invalidate the cache, making this next run flaky
-    if not sys.dont_write_bytecode:
-        testdir.tmpdir.join("__pycache__").remove()
+    testdir.tmpdir.join("__pycache__").remove()
     testdir.makepyfile(contents.format(assert_value="0", strict="True"))
     result = testdir.runpytest("--sw", "-v")
     result.stdout.fnmatch_lines(
