@@ -1,12 +1,7 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import gc
 
 import pytest
-from _pytest.main import EXIT_NOTESTSCOLLECTED
+from _pytest.main import ExitCode
 
 
 def test_simple_unittest(testdir):
@@ -60,7 +55,7 @@ def test_isclasscheck_issue53(testdir):
     """
     )
     result = testdir.runpytest(testpath)
-    assert result.ret == EXIT_NOTESTSCOLLECTED
+    assert result.ret == ExitCode.NO_TESTS_COLLECTED
 
 
 def test_setup(testdir):
@@ -388,7 +383,7 @@ def test_testcase_custom_exception_info(testdir, type):
 
 
 def test_testcase_totally_incompatible_exception_info(testdir):
-    (item,) = testdir.getitems(
+    item, = testdir.getitems(
         """
         from unittest import TestCase
         class MyTestCase(TestCase):
@@ -416,7 +411,7 @@ def test_module_level_pytestmark(testdir):
     reprec.assertoutcome(skipped=1)
 
 
-class TestTrialUnittest(object):
+class TestTrialUnittest:
     def setup_class(cls):
         cls.ut = pytest.importorskip("twisted.trial.unittest")
         # on windows trial uses a socket for a reactor and apparently doesn't close it properly
@@ -482,9 +477,6 @@ class TestTrialUnittest(object):
                     pass
         """
         )
-        from _pytest.compat import _is_unittest_unexpected_success_a_failure
-
-        should_fail = _is_unittest_unexpected_success_a_failure()
         result = testdir.runpytest("-rxs", *self.ignore_unclosed_socket_warning)
         result.stdout.fnmatch_lines_random(
             [
@@ -495,12 +487,10 @@ class TestTrialUnittest(object):
                 "*i2wanto*",
                 "*sys.version_info*",
                 "*skip_in_method*",
-                "*1 failed*4 skipped*3 xfailed*"
-                if should_fail
-                else "*4 skipped*3 xfail*1 xpass*",
+                "*1 failed*4 skipped*3 xfailed*",
             ]
         )
-        assert result.ret == (1 if should_fail else 0)
+        assert result.ret == 1
 
     def test_trial_error(self, testdir):
         testdir.makepyfile(
@@ -714,7 +704,7 @@ def test_unorderable_types(testdir):
     )
     result = testdir.runpytest()
     assert "TypeError" not in result.stdout.str()
-    assert result.ret == EXIT_NOTESTSCOLLECTED
+    assert result.ret == ExitCode.NO_TESTS_COLLECTED
 
 
 def test_unittest_typerror_traceback(testdir):
@@ -768,22 +758,17 @@ def test_unittest_expected_failure_for_passing_test_is_fail(testdir, runner):
             unittest.main()
     """
     )
-    from _pytest.compat import _is_unittest_unexpected_success_a_failure
 
-    should_fail = _is_unittest_unexpected_success_a_failure()
     if runner == "pytest":
         result = testdir.runpytest("-rxX")
         result.stdout.fnmatch_lines(
-            [
-                "*MyTestCase*test_passing_test_is_fail*",
-                "*1 failed*" if should_fail else "*1 xpassed*",
-            ]
+            ["*MyTestCase*test_passing_test_is_fail*", "*1 failed*"]
         )
     else:
         result = testdir.runpython(script)
         result.stderr.fnmatch_lines(["*1 test in*", "*(unexpected successes=1)*"])
 
-    assert result.ret == (1 if should_fail else 0)
+    assert result.ret == 1
 
 
 @pytest.mark.parametrize(
@@ -955,7 +940,7 @@ def test_class_method_containing_test_issue1558(testdir):
 
 
 @pytest.mark.parametrize(
-    "base", ["six.moves.builtins.object", "unittest.TestCase", "unittest2.TestCase"]
+    "base", ["builtins.object", "unittest.TestCase", "unittest2.TestCase"]
 )
 def test_usefixtures_marker_on_unittest(base, testdir):
     """#3498"""
